.. IVPM documentation master file, created by
   sphinx-quickstart on Sun Apr 17 19:30:15 2022.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to IVPM's documentation!
================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:
   
   introduction
   getting_started
   caching
   reference



Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
